@@ -12,7 +12,7 @@
 #    dse1.function.tests(verbose=T)    
 #    example.verify.data(eg1.DSE.data.diff, fuzz.small=1e-12, verbose=T)  
 # # The following gave several..NOT CORRECT in R. It needs est.VARX.ar (not in earlier versions of R).
-# # example.tests(eg1.DSE.data.diff,fuzz.small=1e-12, verbose=T)
+# # example.tests(eg1.DSE.data.diff,fuzz.small=1e-12, verbose=TRUE)
 
 #####################
 
@@ -30,7 +30,7 @@
 fuzz.small <- 1e-14
 fuzz.large <- 1e-10
 digits <- 18
-all.ok <- T  
+all.ok <- TRUE  
 
 
 test.rng <- list(kind="Wichmann-Hill",seed=c(979,1479,1542),normal.kind="Box-Muller")
@@ -53,10 +53,10 @@ test.rng <- list(kind="Wichmann-Hill",seed=c(979,1479,1542),normal.kind="Box-Mul
 #  lsfit produces warning messages in the following
 #  z$output[100,] <-NA
 #  z <- est.VARX.ls(z, warn=F)
-  VARmodel  <-  est.VARX.ar(eg1.DSE.data.diff, re.add.means=F, warn=F)
+  VARmodel  <-  est.VARX.ar(eg1.DSE.data.diff, re.add.means=FALSE, warn=FALSE)
   SSmodel  <- to.SS(VARmodel)
   ok <- fuzz.large > abs(VARmodel$estimates$like[1] -
-               l(SSmodel, eg1.DSE.data.diff, warn=F)$estimates$like[1])
+               l(SSmodel, eg1.DSE.data.diff, warn=FALSE)$estimates$like[1])
   ok <- ok & is.TSestModel(VARmodel) & is.TSmodel(VARmodel$model)
   ok <- ok & (nseriesInput(VARmodel) == nseriesInput(SSmodel))
   ok <- ok & (nseriesInput(VARmodel) == nseriesInput(VARmodel$data))
@@ -66,7 +66,7 @@ test.rng <- list(kind="Wichmann-Hill",seed=c(979,1479,1542),normal.kind="Box-Mul
   B <- t(chol(VARmodel$estimates$cov))
   VARmodelB$B <- array(B, c(1,dim(B)))  # has B != I
   VARmodelB <- set.parameters(VARmodelB)
-  VARmodelB <- l(VARmodelB,VARmodel$data, warn=F)
+  VARmodelB <- l(VARmodelB,VARmodel$data, warn=FALSE)
 
    good <- VARmodel$estimates$pred
    tst  <- VARmodelB$estimates$pred
@@ -75,7 +75,7 @@ test.rng <- list(kind="Wichmann-Hill",seed=c(979,1479,1542),normal.kind="Box-Mul
 
    if (any(is.na(error)) || any(is.nan(error)) || fuzz.large < error) 
      {print.test.value(c(tst), digits=18)
-      all.ok <- F  
+      all.ok <- FALSE  
      }
 
   if (! all.ok) stop("some tests FAILED")
